@@ -1,7 +1,6 @@
 """
 Worker and work related services
 """
-
 from abc import ABC, abstractmethod
 
 
@@ -9,10 +8,24 @@ class WorkerContract(ABC):
     """Contacts for worker"""
 
     @abstractmethod
-    def __work__(self): pass
+    def __before_main__(self) -> None:
+        pass
+
+    @abstractmethod
+    def __main__(self) -> None:
+        pass
+
+    @abstractmethod
+    def __after_main__(self) -> object:
+        pass
+
+    def __work__(self) -> object:
+        self.__before_main__()
+        self.__main__()
+        return self.__after_main__()
 
 
-def handle_worker(worker: WorkerContract):
+def handle_worker(worker: WorkerContract) -> object:
     """
     Run a WorkerContract's contracts
 
