@@ -3,7 +3,7 @@ Validation rules and supporting libs for version module
 """
 from chk.modules.version.constants import VersionStore
 
-version_schema = {
+version_schema_http = {
     'version': {
         'required': True,
         'type': 'string',
@@ -11,3 +11,12 @@ version_schema = {
         'allowed': VersionStore.request_versions
     }
 }
+
+version_schema_testcase = {
+    'version': {
+        'required': True,
+        'type': 'string',
+        'empty': False,
+        'allowed': VersionStore.testcase_versions
+    }
+}
